@@ -22,7 +22,7 @@ impl Icons {
     const CAD: char             = '\u{f0eeb}'; // 󰻫
     const CLOCK: char           = '\u{f43a}';  // 
     const COMPRESSED: char      = '\u{f410}';  // 
-    const CONFIG: char          = '\u{e615}';  // 
+    const CONFIG: char          = '\u{f107b}'; // 󱁻
     const CSS3: char            = '\u{e749}';  // 
     const DATABASE: char        = '\u{f1c0}';  // 
     const DIFF: char            = '\u{f440}';  // 
@@ -36,8 +36,8 @@ impl Icons {
     const ESLINT: char          = '\u{e655}';  // 
     const FILE: char            = '\u{f15b}';  // 
     const FILE_3D: char         = '\u{f01a7}'; // 󰆧
-    const FILE_OUTLINE: char    = '\u{f016}';  // 
     const FOLDER: char          = '\u{e5ff}';  // 
+    const FOLDER_BUILD: char    = '\u{f19fc}'; // 󱧼
     const FOLDER_CONFIG: char   = '\u{e5fc}';  // 
     const FOLDER_EXERCISM: char = '\u{ebe5}';  // 
     const FOLDER_GIT: char      = '\u{e5fb}';  // 
@@ -47,11 +47,12 @@ impl Icons {
     const FOLDER_NPM: char      = '\u{e5fa}';  // 
     const FOLDER_OCAML: char    = '\u{e67a}';  // 
     const FOLDER_OPEN: char     = '\u{f115}';  // 
+    const FILE_UNKNOW: char     = '\u{f086f}'; // 󰡯
     const FONT: char            = '\u{f031}';  // 
     const FREECAD: char         = '\u{f336}';  // 
     const GIMP: char            = '\u{f338}';  // 
     const GIST_SECRET: char     = '\u{eafa}';  // 
-    const GIT: char             = '\u{f1d3}';  // 
+    const GIT: char             = '\u{f02a2}'; // 󰊢
     const GODOT: char           = '\u{e65f}';  // 
     const GRADLE: char          = '\u{e660}';  // 
     const GRAPH: char           = '\u{f1049}'; // 󱁉
@@ -138,6 +139,7 @@ impl Icons {
     const SQLITE: char          = '\u{e7c4}';  // 
     const SUBLIME: char         = '\u{e7aa}';  // 
     const SUBTITLE: char        = '\u{f0a16}'; // 󰨖
+    const TCL: char             = '\u{f06d3}'; // 󰛓
     const TERRAFORM: char       = '\u{f1062}'; // 󱁢
     const TEXT: char            = '\u{f15c}';  // 
     const TYPST: char           = '\u{f37f}';  // 
@@ -150,6 +152,7 @@ impl Icons {
     const VIM: char             = '\u{e7c5}';  // 
     const WRENCH: char          = '\u{f0ad}';  // 
     const XML: char             = '\u{f05c0}'; // 󰗀
+    const XORG:char             = '\u{f369}';  // 
     const YAML: char            = '\u{e6a8}';  // 
     const YARN: char            = '\u{e6a7}';  // 
 }
@@ -165,6 +168,7 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     ".opam"               => Icons::FOLDER_OCAML,   // 
     ".ssh"                => Icons::FOLDER_KEY,     // 󰢬
     ".Trash"              => '\u{f1f8}',            // 
+    "build"               => Icons::FOLDER_BUILD,   // 󱧼
     "config"              => Icons::FOLDER_CONFIG,  // 
     "Contacts"            => '\u{f024c}',           // 󰉌
     "cron.d"              => Icons::FOLDER_CONFIG,  // 
@@ -174,6 +178,7 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     "cron.monthly"        => Icons::FOLDER_CONFIG,  // 
     "cron.weekly"         => Icons::FOLDER_CONFIG,  // 
     "Desktop"             => '\u{f108}',            // 
+    "Documents"           => '\u{f0c82}',           // 󰲂
     "Downloads"           => '\u{f024d}',           // 󰉍
     "etc"                 => Icons::FOLDER_CONFIG,  // 
     "Favorites"           => '\u{f069d}',           // 󰚝
@@ -185,8 +190,10 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     "Music"               => '\u{f1359}',           // 󱍙
     "node_modules"        => Icons::FOLDER_NPM,     // 
     "npm_cache"           => Icons::FOLDER_NPM,     // 
+    "pacman.d"            => Icons::FOLDER_CONFIG,  // 
     "pam.d"               => Icons::FOLDER_KEY,     // 󰢬
     "Pictures"            => '\u{f024f}',           // 󰉏
+    "src"                 => '\u{f08de}',           // 󰣞
     "ssh"                 => Icons::FOLDER_KEY,     // 󰢬
     "sudoers.d"           => Icons::FOLDER_KEY,     // 󰢬
     "Videos"              => '\u{f03d}',            // 
@@ -206,8 +213,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".bash_logout"        => Icons::SHELL,          // 󱆃
     ".bash_profile"       => Icons::SHELL,          // 󱆃
     ".CFUserTextEncoding" => Icons::OS_APPLE,       // 
-    ".clang-format"       => Icons::CONFIG,         // 
-    ".clang-tidy"         => Icons::CONFIG,         // 
+    ".clang-format"       => Icons::CONFIG,         // 󱁻
+    ".clang-tidy"         => Icons::CONFIG,         // 󱁻
     ".codespellrc"        => '\u{f04c6}',           // 󰓆
     ".condarc"            => '\u{e715}',            // 
     ".cshrc"              => Icons::SHELL,          // 󱆃
@@ -223,29 +230,29 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".eslintrc.yml"       => Icons::ESLINT,         // 
     ".gcloudignore"       => '\u{f11f6}',           // 󱇶
     ".fennelrc"           => Icons::LANG_FENNEL,    // 
-    ".gitattributes"      => Icons::GIT,            // 
-    ".git-blame-ignore-revs" => Icons::GIT,         // 
-    ".gitconfig"          => Icons::GIT,            // 
-    ".gitignore"          => Icons::GIT,            // 
-    ".gitignore_global"   => Icons::GIT,            // 
+    ".gitattributes"      => Icons::GIT,            // 󰊢
+    ".git-blame-ignore-revs" => Icons::GIT,         // 󰊢
+    ".gitconfig"          => Icons::GIT,            // 󰊢
+    ".gitignore"          => Icons::GIT,            // 󰊢
+    ".gitignore_global"   => Icons::GIT,            // 󰊢
     ".gitlab-ci.yml"      => '\u{f296}',            // 
-    ".gitmodules"         => Icons::GIT,            // 
+    ".gitmodules"         => Icons::GIT,            // 󰊢
     ".gtkrc-2.0"          => Icons::GTK,            // 
     ".gvimrc"             => Icons::VIM,            // 
-    ".htaccess"           => Icons::CONFIG,         // 
-    ".htpasswd"           => Icons::CONFIG,         // 
+    ".htaccess"           => Icons::CONFIG,         // 󱁻
+    ".htpasswd"           => Icons::CONFIG,         // 󱁻
     ".idea"               => Icons::INTELLIJ,       // 
     ".ideavimrc"          => Icons::VIM,            // 
-    ".inputrc"            => Icons::CONFIG,         // 
+    ".inputrc"            => Icons::CONFIG,         // 󱁻
     ".kshrc"              => Icons::SHELL,          // 󱆃
     ".login"              => Icons::SHELL,          // 󱆃
     ".logout"             => Icons::SHELL,          // 󱆃
-    ".luacheckrc"         => Icons::CONFIG,         // 
-    ".luaurc"             => Icons::CONFIG,         // 
+    ".luacheckrc"         => Icons::CONFIG,         // 󱁻
+    ".luaurc"             => Icons::CONFIG,         // 󱁻
     ".nanorc"             => '\u{e838}',            // 
     ".nuxtrc"             => '\u{f1106}',           // 󱄆
     ".ocamlinit"          => Icons::LANG_OCAML,     // 
-    ".mailmap"            => Icons::GIT,            // 
+    ".mailmap"            => Icons::GIT,            // 󰊢
     ".node_repl_history"  => Icons::NODEJS,         // 
     ".npmignore"          => Icons::NPM,            // 
     ".npmrc"              => Icons::NPM,            // 
@@ -259,7 +266,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".prettierrc.yml"     => '\u{e6b4}',            // 
     ".parentlock"         => Icons::LOCK,           // 
     ".profile"            => Icons::SHELL,          // 󱆃
-    ".pylintrc"           => Icons::CONFIG,         // 
+    ".pylintrc"           => Icons::CONFIG,         // 󱁻
     ".python_history"     => Icons::LANG_PYTHON,    // 
     ".rustfmt.toml"       => Icons::LANG_RUST,      // 
     ".rvm"                => Icons::LANG_RUBY,      // 
@@ -269,9 +276,10 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     ".tcshrc"             => Icons::SHELL,          // 󱆃
     ".viminfo"            => Icons::VIM,            // 
     ".vimrc"              => Icons::VIM,            // 
-    ".Xauthority"         => Icons::CONFIG,         // 
-    ".xinitrc"            => Icons::CONFIG,         // 
-    ".Xresources"         => Icons::CONFIG,         // 
+    ".Xauthority"         => Icons::XORG,           // 
+    ".xinitrc"            => Icons::XORG,           // 
+    ".Xresources"         => Icons::XORG,           // 
+    ".xsession"           => Icons::XORG,           // 
     ".yarnrc"             => Icons::YARN,           // 
     ".zlogin"             => Icons::SHELL,          // 󱆃
     ".zlogout"            => Icons::SHELL,          // 󱆃
@@ -302,17 +310,17 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "CODE_OF_CONDUCT.md"  => '\u{f4ae}',            // 
     "composer.json"       => Icons::LANG_PHP,       // 
     "composer.lock"       => Icons::LANG_PHP,       // 
-    "config"              => Icons::CONFIG,         // 
+    "config"              => Icons::CONFIG,         // 󱁻
     "config.ru"           => Icons::LANG_RUBY,      // 
-    "config.status"       => Icons::CONFIG,         // 
+    "config.status"       => Icons::CONFIG,         // 󱁻
     "configure"           => Icons::WRENCH,         // 
-    "configure.ac"        => Icons::CONFIG,         // 
-    "configure.in"        => Icons::CONFIG,         // 
+    "configure.ac"        => Icons::CONFIG,         // 󱁻
+    "configure.in"        => Icons::CONFIG,         // 󱁻
     "constraints.txt"     => Icons::LANG_PYTHON,    // 
     "COPYING"             => Icons::LICENSE,        // 
     "COPYRIGHT"           => Icons::LICENSE,        // 
-    "crontab"             => Icons::CONFIG,         // 
-    "crypttab"            => Icons::CONFIG,         // 
+    "crontab"             => Icons::CONFIG,         // 󱁻
+    "crypttab"            => Icons::CONFIG,         // 󱁻
     "csh.cshrc"           => Icons::SHELL,          // 󱆃
     "csh.login"           => Icons::SHELL,          // 󱆃
     "csh.logout"          => Icons::SHELL,          // 󱆃
@@ -326,7 +334,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "dune-project"        => Icons::WRENCH,         // 
     "Earthfile"           => '\u{f0ac}',            // 
     "COMMIT_EDITMSG"      => Icons::GIT,            // 
-    "environment"         => Icons::CONFIG,         // 
+    "environment"         => Icons::CONFIG,         // 󱁻
     "favicon.ico"         => '\u{e623}',            // 
     "flake.lock"          => '\u{f313}',            // 
     "fennelrc"            => Icons::LANG_FENNEL,    // 
@@ -354,7 +362,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "gulpfile.js"         => Icons::GULP,           // 
     "gulpfile.ls"         => Icons::GULP,           // 
     "heroku.yml"          => '\u{e77b}',            // 
-    "hostname"            => Icons::CONFIG,         // 
+    "hostname"            => Icons::CONFIG,         // 󱁻
     "hypridle.conf"       => '\u{f359}',            // 
     "hyprland.conf"       => '\u{f359}',            // 
     "hyprlock.conf"       => '\u{f359}',            // 
@@ -367,8 +375,8 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "id_ed25519"          => Icons::PRIVATE_KEY,    // 󰌆
     "id_ed25519_sk"       => Icons::PRIVATE_KEY,    // 󰌆
     "id_rsa"              => Icons::PRIVATE_KEY,    // 󰌆
-    "index.theme"     => '\u{ee72}',           // 
-    "inputrc"             => Icons::CONFIG,         // 
+    "index.theme"         => '\u{ee72}',            // 
+    "inputrc"             => Icons::CONFIG,         // 󱁻
     "Jenkinsfile"         => '\u{e66e}',            // 
     "jsconfig.json"       => Icons::LANG_JAVASCRIPT,// 
     "Justfile"            => Icons::WRENCH,         // 
@@ -436,7 +444,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "SECURITY.md"         => '\u{f0483}',           // 󰒃
     "settings.gradle.kts" => Icons::GRADLE,         // 
     "shadow"              => Icons::LOCK,           // 
-    "shells"              => Icons::CONFIG,         // 
+    "shells"              => Icons::CONFIG,         // 󱁻
     "sudoers"             => Icons::LOCK,           // 
     "sxhkdrc"             => Icons::CONFIG,         // 
     "sym-lib-table"       => Icons::KICAD,          // 
@@ -447,10 +455,12 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "Vagrantfile"         => '\u{2371}',            // ⍱
     "vlcrc"               => '\u{f057c}',           // 󰕼
     "webpack.config.js"   => '\u{f072b}',           // 󰜫
+    "xorg.conf"           => Icons::XORG,           // 
+    "xsettingsd.conf"     => Icons::XORG,           // 
     "weston.ini"          => '\u{f367}',            // 
-    "xmobarrc"            => '\u{f35e}',            // 
-    "xmobarrc.hs"         => '\u{f35e}',            // 
-    "xmonad.hs"           => '\u{f35e}',            // 
+    "xmobarrc"            => Icons::XORG,           // 
+    "xmobarrc.hs"         => Icons::XORG,           // 
+    "xmonad.hs"           => Icons::XORG,           // 
     "yarn.lock"           => Icons::YARN,           // 
     "zlogin"              => Icons::SHELL,          // 󱆃
     "zlogout"             => Icons::SHELL,          // 󱆃
@@ -524,7 +534,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "cbz"            => Icons::IMAGE,            // 
     "cc"             => Icons::LANG_CPP,         // 
     "cert"           => Icons::GIST_SECRET,      // 
-    "cfg"            => Icons::CONFIG,           // 
+    "cfg"            => Icons::CONFIG,           // 󱁻
     "cjs"            => Icons::LANG_JAVASCRIPT,  // 
     "class"          => Icons::LANG_JAVA,        // 
     "clj"            => '\u{e768}',              // 
@@ -536,8 +546,8 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "coffee"         => '\u{f0f4}',              // 
     "com"            => '\u{e629}',              // 
     "conda"          => '\u{e715}',              // 
-    "conf"           => Icons::CONFIG,           // 
-    "config"         => Icons::CONFIG,           // 
+    "conf"           => Icons::CONFIG,           // 󱁻
+    "config"         => Icons::CONFIG,           // 󱁻
     "cow"            => '\u{f019a}',             // 󰆚
     "cp"             => Icons::LANG_CPP,         // 
     "cpio"           => Icons::COMPRESSED,       // 
@@ -652,7 +662,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "gemspec"        => Icons::LANG_RUBY,        // 
     "gform"          => '\u{f298}',              // 
     "gif"            => Icons::IMAGE,            // 
-    "git"            => Icons::GIT,              // 
+    "git"            => Icons::GIT,              // 󰊢
     "gleam"          => Icons::LANG_GLEAM,       // 󰦥
     "gm1"            => Icons::EDA_PCB,          // 
     "gml"            => Icons::EDA_PCB,          // 
@@ -706,7 +716,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "img"            => Icons::DISK_IMAGE,       // 
     "iml"            => Icons::INTELLIJ,         // 
     "info"           => Icons::INFO,             // 
-    "ini"            => Icons::CONFIG,           // 
+    "ini"            => Icons::CONFIG,           // 󱁻
     "inl"            => Icons::LANG_C,           // 
     "ipynb"          => Icons::NOTEBOOK,              // 
     "ino"            => Icons::LANG_ARDUINO,     // 
@@ -839,6 +849,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ogg"            => Icons::AUDIO,            // 
     "ogm"            => Icons::VIDEO,            // 
     "ogv"            => Icons::VIDEO,            // 
+    "opam"           => '\u{f0627}',             // 󰘧
     "opml"           => Icons::XML,              // 󰗀
     "opus"           => Icons::AUDIO,            // 
     "orf"            => Icons::IMAGE,            // 
@@ -997,14 +1008,13 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "swf"            => Icons::AUDIO,            // 
     "swift"          => '\u{e755}',              // 
     "t"              => Icons::LANG_PERL,        // 
-    "tape"           => '\u{F0A1B}',             // 󰨛
+    "tbc"            => Icons::TCL,              // 󰛓
     "tar"            => Icons::COMPRESSED,       // 
     "taz"            => Icons::COMPRESSED,       // 
-    "tbc"            => '\u{f06d3}',             // 󰛓
     "tbz"            => Icons::COMPRESSED,       // 
     "tbz2"           => Icons::COMPRESSED,       // 
     "tc"             => Icons::DISK_IMAGE,       // 
-    "tcl"            => '\u{f06d3}',             // 󰛓
+    "tcl"            => Icons::TCL,              // 󰛓
     "tex"            => Icons::LANG_TEX,         // 
     "tf"             => Icons::TERRAFORM,        // 󱁢
     "tfstate"        => Icons::TERRAFORM,        // 󱁢
@@ -1119,6 +1129,6 @@ pub fn icon_for_file(file: &File<'_>) -> char {
     } else if let Some(ext) = file.ext.as_ref() {
         *EXTENSION_ICONS.get(ext.as_str()).unwrap_or(&Icons::FILE) // 
     } else {
-        Icons::FILE_OUTLINE // 
+        Icons::FILE_UNKNOW // 󰡯
     }
 }
